%define _buildid .12

%global py26nvr python26-pycurl-%{version}-%{release}
%global py26builddir %{_builddir}/%{py26nvr}
%global py26doc ../%{py26nvr}

%global py27nvr python27-pycurl-%{version}-%{release}
%global py27builddir %{_builddir}/%{py27nvr}
%global py27doc ../%{py27nvr}

%bcond_without tests # with

%global upstream_name pycurl
# During its initialization, PycURL checks that the actual libcurl version
# is not lower than the one used when PycURL was built.
# Yes, that should be handled by library versioning (which would then get
# automatically reflected by rpm).
# For now, we have to reflect that dependency.
%global libcurl_sed '/^#define LIBCURL_VERSION "/!d;s/"[^"]*$//;s/.*"//;q'
%global curlver_h /usr/include/curl/curlver.h
%global libcurl_ver %(sed %{libcurl_sed} %{curlver_h} 2>/dev/null || echo 0)

Name: python-pycurl
Version: 7.19.0
Release: 17%{?_buildid}%{?dist}
Summary: A Python interface to libcurl
Group: Development/Languages
License: LGPLv2+ or MIT
URL: http://pycurl.sourceforge.net/
Source0: http://pycurl.sourceforge.net/download/pycurl-%{version}.tar.gz

# upstream patches
Patch1: 0001-No-longer-keep-copies-of-string-options-since-this-i.patch
Patch2: 0002-Fixes-https-sourceforge.net-tracker-func-detail-aid-.patch
Patch3: 0003-Fixes-refcount-bug-and-provides-better-organization-.patch
Patch4: 0004-Test-for-reset-fixes-refcount-bug.patch
Patch5: 0005-Updating-ChangeLog-with-relevant-changes.patch

# downstream patches
Patch101: 0101-test_internals.py-add-a-test-for-ref-counting-of-res.patch
Patch102: 0102-pycurl.c-eliminate-duplicated-code-in-util_write_cal.patch
Patch103: 0103-pycurl.c-allow-to-return-1-from-write-callback.patch
Patch104: 0104-test_write_abort.py-test-returning-1-from-write-call.patch
Patch105: 0105-add-the-GLOBAL_ACK_EINTR-constant-to-the-list-of-exp.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: python26
BuildRequires: python27

%description
PycURL is a Python interface to libcurl. PycURL can be used to fetch
objects identified by a URL from a Python program, similar to the
urllib Python module. PycURL is mature, very fast, and supports a lot
of features.

%package -n python26-pycurl
Summary: A Python interface to libcurl
BuildRequires: python26-devel
BuildRequires: curl-devel >= 7.19.0
BuildRequires: openssl-devel
Requires: libcurl >= %{libcurl_ver}
Requires: keyutils-libs
Provides: python-pycurl = %{version}-%{release}
Provides: pycurl = %{version}-%{release}
Provides: pycurl%{?_isa} = %{version}-%{release}
Provides: python-pycurl%{?_isa} = %{version}-%{release}
Obsoletes: python-pycurl <= 7.19.0-17.9.amzn1

%description -n python26-pycurl
PycURL is a Python interface to libcurl. PycURL can be used to fetch
objects identified by a URL from a Python program, similar to the
urllib Python module. PycURL is mature, very fast, and supports a lot
of features.

This package is meant to be used with Python 2.6.

%package -n python27-pycurl
Summary: A Python interface to libcurl
BuildRequires: python27-devel
BuildRequires: curl-devel >= 7.19.0
BuildRequires: openssl-devel
Requires: libcurl >= %{libcurl_ver}
Requires: keyutils-libs

%description -n python27-pycurl
PycURL is a Python interface to libcurl. PycURL can be used to fetch
objects identified by a URL from a Python program, similar to the
urllib Python module. PycURL is mature, very fast, and supports a lot
of features.

This package is meant to be used with Python 2.7.

%prep
%setup -q -n %{upstream_name}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
chmod a-x examples/*

%build
rm -rf %{py26builddir}
mkdir -p %{py26builddir}
cp -a * %{py26builddir}
pushd %{py26builddir}
CFLAGS="$RPM_OPT_FLAGS -DHAVE_CURL_OPENSSL" %{__python26} setup.py build 
popd

rm -rf %{py27builddir}
mkdir -p %{py27builddir}
cp -a * %{py27builddir}
pushd %{py27builddir}
CFLAGS="$RPM_OPT_FLAGS -DHAVE_CURL_OPENSSL" %{__python27} setup.py build 
popd

%install
rm -rf %{buildroot}

pushd %{py26builddir}
%{__python26} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd
rm -rf %{buildroot}%{_datadir}/doc/pycurl

pushd %{py27builddir}
%{__python27} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd
rm -rf %{buildroot}%{_datadir}/doc/pycurl

%check
%if %{with tests}
pushd %{py26builddir}
export PYTHONPATH=%{buildroot}%{python26_sitearch}
make test PYTHON=%{__python26}
popd
pushd %{py27builddir}
export PYTHONPATH=%{buildroot}%{python27_sitearch}
make test PYTHON=%{__python27}
popd
%endif

%clean
rm -rf %{buildroot}
rm -rf %{py26builddir}
rm -rf %{py27builddir}

%files -n python26-pycurl
%doc COPYING COPYING2 ChangeLog README TODO examples doc tests
%dir %{python26_sitearch}/curl
%{python26_sitearch}/curl/__init__.py
%{python26_sitearch}/curl/__init__.py?
%{python26_sitearch}/pycurl.so
%{python26_sitearch}/pycurl-%{version}*.egg-info

%files -n python27-pycurl
%doc COPYING COPYING2 ChangeLog README TODO examples doc tests
%dir %{python27_sitearch}/curl
%{python27_sitearch}/curl/__init__.py
%{python27_sitearch}/curl/__init__.py?
%{python27_sitearch}/pycurl.so
%{python27_sitearch}/pycurl-%{version}*.egg-info

%changelog
* Wed Feb 25 2015 Ben Cressey <bcressey@amazon.com>
- fix glob on egg-info

* Tue Feb 3 2015 Ben Cressey <bcressey@amazon.com>
- build for multiple pythons

* Fri Sep 12 2014 Rodrigo Novo <rodarvus@amazon.com>
- Explicitly describe file list on %%files

* Wed May 7 2014 Cristian Gafton <gafton@amazon.com>
- import source package RHEL7/python-pycurl-7.19.0-17.el7

* Fri Jan 24 2014 Daniel Mach <dmach@redhat.com> - 7.19.0-17
- Mass rebuild 2014-01-24

* Fri Dec 27 2013 Daniel Mach <dmach@redhat.com> - 7.19.0-16
- Mass rebuild 2013-12-27

* Fri Dec 13 2013 Cristian Gafton <gafton@amazon.com>
- import source package RHEL7/python-pycurl-7.19.0-15.1.el7

* Tue Apr 09 2013 Kamil Dudka <kdudka@redhat.com> - 7.19.0-15.1
- add the GLOBAL_ACK_EINTR constant to the list of exported symbols (#920589)

* Wed Mar 06 2013 Kamil Dudka <kdudka@redhat.com> - 7.19.0-15
- allow to return -1 from the write callback (#857875) 
- remove the patch for curl-config --static-libs no longer needed
- run the tests against the just built pycurl, not the system one

* Mon Feb 25 2013 Kamil Dudka <kdudka@redhat.com> - 7.19.0-14
- apply bug-fixes committed to upstream CVS since 7.19.0 (fixes #896025)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.19.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Aug 22 2012 Jan Synáček <jsynacek@redhat.com> - 7.19.0-12
- Improve spec

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.19.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.19.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun May 22 2011 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/python-pycurl-7.19.0-8.el6

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.19.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec 20 2010 Dennis Gilmore <dennis@ausil.us> - 7.19.0-8
- add Missing Requires on keyutils-libs

* Tue Aug 17 2010 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.19.0-7
- Add patch developed by David Malcolm to fix segfaults caused by a missing incref

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 7.19.0-6
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Mon Jul 12 2010 Nathan Blackham <blackham@amazon.com>
- rebuilding on python26

* Fri Jul 9 2010 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/python-pycurl-7.19.0-5.el6
- import source package RHEL6/python-pycurl-7.19.0-4.1.el6
- setup complete for package python-pycurl

* Tue Mar  2 2010 Karel Klic <kklic@redhat.com> - 7.19.0-5
- Package COPYING2 file
- Added MIT as a package license

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.19.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Apr 17 2009 Stepan Kasal <skasal@redhat.com> - 7.19.0-3
- fix typo in the previous change

* Fri Apr 17 2009 Stepan Kasal <skasal@redhat.com> - 7.19.0-2
- add a require to reflect a dependency on libcurl version (#496308)

* Thu Mar  5 2009 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.19.0-1
- Update to 7.19.0

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.18.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 7.18.2-2
- Rebuild for Python 2.6

* Thu Jul  3 2008 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.18.2-1
- Update to 7.18.2
- Thanks to Ville Skyttä re-enable the tests and fix a minor problem
  with the setup.py. (Bug # 45400)

* Thu Jun  5 2008 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.18.1-1
- Update to 7.18.1
- Disable tests because it's not testing the built library, it's trying to
  test an installed library.

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 7.16.4-3
- Autorebuild for GCC 4.3

* Thu Jan  3 2008 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.16.4-2
- BR openssl-devel

* Wed Aug 29 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.16.4-1
- Update to 7.16.4
- Update license tag.

* Sat Jun  9 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.16.2.1-1
- Update to released version.

* Thu Dec  7 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.16.0-0.1.20061207
- Update to a CVS snapshot since development has a newer version of curl than is in FC <= 6

* Thu Dec  7 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.15.5.1-4
- Add -DHAVE_CURL_OPENSSL to fix PPC build problem.

* Thu Dec  7 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.15.5.1-3
- Don't forget to Provide: pycurl!!!

* Thu Dec  7 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.15.5.1-2
- Remove INSTALL from the list of documentation
- Use python_sitearch for all of the files

* Thu Dec  7 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 7.15.5.1-1
- First version for Fedora Extras
